# Registration AEA AW1

This is an agent to register for Agent World 1.

## Description

This agent uses the `fetchai/simple_service_registration` skill to register information about itself on the sOEF. It uses the `fetchai/simple_service_search` skill to find the agent handling confirmation of registration in AW1. It uses the `fetchai/registration_aw1` skill to deal with the registration flow, including signing of messages.

## Links
